@@ -14,7 +14,7 @@ Airflow REST API definition
 
 import logging
 import traceback
-from typing import Optional
+from typing import Any, Optional
 
 from airflow import settings
 from airflow.models import DagBag, DagModel
@@ -35,6 +35,7 @@ from openmetadata.api.utils import jwt_token_secure
 from openmetadata.helpers import clean_dag_id
 from openmetadata.operations.delete import delete_dag_id
 from openmetadata.operations.deploy import DagDeployer
+from openmetadata.operations.kill_all import kill_all
 from openmetadata.operations.last_dag_logs import last_dag_logs
 from openmetadata.operations.state import disable_dag, enable_dag
 from openmetadata.operations.status import status
@@ -47,6 +48,8 @@ from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipel
 )
 from metadata.ingestion.api.parser import parse_test_connection_request_gracefully
 
+MISSING_DAG_ID_EXCEPTION_MSG = "Missing dag_id argument in the request"
+
 
 class REST_API(AppBuilderBaseView):
     """API View which extends either flask AppBuilderBaseView or flask AdminBaseView"""
@@ -60,9 +63,28 @@ class REST_API(AppBuilderBaseView):
         return dagbag
 
     @staticmethod
-    def get_request_arg(req, arg) -> Optional[str]:
+    def get_request_arg(req, arg) -> Optional[Any]:
         return req.args.get(arg) or req.form.get(arg)
 
+    def get_arg_dag_id(self) -> Optional[str]:
+        """
+        Try to fetch the dag_id from the args
+        and clean it
+        """
+        raw_dag_id = self.get_request_arg(request, "dag_id")
+
+        return clean_dag_id(raw_dag_id)
+
+    @staticmethod
+    def get_request_dag_id() -> Optional[str]:
+        """
+        Try to fetch the dag_id from the JSON request
+        and clean it
+        """
+        raw_dag_id = request.get_json().get("dag_id")
+
+        return clean_dag_id(raw_dag_id)
+
     # '/' Endpoint where the Admin page is which allows you to view the APIs available and trigger them
     @app_builder_expose("/")
     def list(self):
@@ -93,6 +115,21 @@ class REST_API(AppBuilderBaseView):
             rbac_authentication_enabled=True,
         )
 
+    @csrf.exempt  # Exempt the CSRF token
+    @app_builder_expose("/health", methods=["GET"])  # for Flask AppBuilder
+    def health(self):
+        """
+        /health endpoint to check Airflow REST status without auth
+        """
+
+        try:
+            return ApiResponse.success({"status": "healthy"})
+        except Exception as err:
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_SERVER_ERROR,
+                error=f"Internal error obtaining REST status - {err} - {traceback.format_exc()}",
+            )
+
     # '/api' REST Endpoint where API requests should all come in
     @csrf.exempt  # Exempt the CSRF token
     @admin_expose("/api", methods=["GET", "POST", "DELETE"])  # for Flask Admin
@@ -119,46 +156,15 @@ class REST_API(AppBuilderBaseView):
 
         # Deciding which function to use based off the API object that was requested.
         # Some functions are custom and need to be manually routed to.
-        if api == "rest_status":
-            return self.rest_status()
-        if api == "deploy_dag":
-            return self.deploy_dag()
-        if api == "trigger_dag":
-            return self.trigger_dag()
-        if api == "test_connection":
-            return self.test_connection()
-        if api == "dag_status":
-            return self.dag_status()
-        if api == "delete_dag":
-            return self.delete_dag()
-        if api == "last_dag_logs":
-            return self.last_dag_logs()
-        if api == "enable_dag":
-            return self.enable_dag()
-        if api == "disable_dag":
-            return self.disable_dag()
+        # The required API name will be the method name to invoke.
+        api_fn = getattr(self, api)
+        if api_fn:
+            return api_fn()
 
         raise ValueError(
             f"Invalid api param {api}. Expected deploy_dag or trigger_dag."
         )
 
-    @staticmethod
-    def rest_status() -> Response:
-        """
-        Check that the Airflow REST is reachable
-        and running correctly.
-        """
-        try:
-            url = AIRFLOW_WEBSERVER_BASE_URL + REST_API_ENDPOINT
-            return ApiResponse.success(
-                {"message": f"Airflow REST {REST_API_PLUGIN_VERSION} running at {url}"}
-            )
-        except Exception as err:
-            return ApiResponse.error(
-                status=ApiResponse.STATUS_SERVER_ERROR,
-                error=f"Internal error obtaining REST status - {err} - {traceback.format_exc()}",
-            )
-
     def deploy_dag(self) -> Response:
         """
         Custom Function for the deploy_dag API
@@ -216,21 +222,17 @@ class REST_API(AppBuilderBaseView):
                 error=f"Internal error testing connection {err} - {traceback.format_exc()}",
             )
 
-    @staticmethod
-    def trigger_dag() -> Response:
+    def trigger_dag(self) -> Response:
         """
         Trigger a dag run
         """
-        request_json = request.get_json()
+        dag_id = self.get_request_dag_id()
 
-        raw_dag_id = request_json.get("workflow_name")
-        if not raw_dag_id:
-            return ApiResponse.bad_request("workflow_name should be informed")
-
-        dag_id = clean_dag_id(raw_dag_id)
+        if not dag_id:
+            return ApiResponse.bad_request(MISSING_DAG_ID_EXCEPTION_MSG)
 
         try:
-            run_id = request_json.get("run_id")
+            run_id = self.get_request_arg(request, "run_id")
             response = trigger(dag_id, run_id)
 
             return response
@@ -246,12 +248,10 @@ class REST_API(AppBuilderBaseView):
         """
         Check the status of a DAG runs
         """
-        raw_dag_id: str = self.get_request_arg(request, "dag_id")
+        dag_id = self.get_arg_dag_id()
 
-        if not raw_dag_id:
-            return ApiResponse.bad_request("Missing dag_id argument in the request")
-
-        dag_id = clean_dag_id(raw_dag_id)
+        if not dag_id:
+            return ApiResponse.bad_request(MISSING_DAG_ID_EXCEPTION_MSG)
 
         try:
             return status(dag_id)
@@ -272,12 +272,10 @@ class REST_API(AppBuilderBaseView):
             "workflow_name": "my_ingestion_pipeline3"
         }
         """
-        raw_dag_id: str = self.get_request_arg(request, "dag_id")
+        dag_id = self.get_arg_dag_id()
 
-        if not raw_dag_id:
-            return ApiResponse.bad_request("workflow_name should be informed")
-
-        dag_id = clean_dag_id(raw_dag_id)
+        if not dag_id:
+            return ApiResponse.bad_request(MISSING_DAG_ID_EXCEPTION_MSG)
 
         try:
             return delete_dag_id(dag_id)
@@ -294,6 +292,7 @@ class REST_API(AppBuilderBaseView):
         Retrieve all logs from the task instances of a last DAG run
         """
         raw_dag_id: str = self.get_request_arg(request, "dag_id")
+        compress: bool = self.get_request_arg(request, "compress")
 
         if not raw_dag_id:
             ApiResponse.bad_request("Missing dag_id parameter in the request")
@@ -301,7 +300,7 @@ class REST_API(AppBuilderBaseView):
         dag_id = clean_dag_id(raw_dag_id)
 
         try:
-            return last_dag_logs(dag_id)
+            return last_dag_logs(dag_id, compress or True)
 
         except Exception as exc:
             logging.info(f"Failed to get last run logs for '{dag_id}'")
@@ -310,18 +309,14 @@ class REST_API(AppBuilderBaseView):
                 error=f"Failed to get last run logs for '{dag_id}' due to {exc} - {traceback.format_exc()}",
             )
 
-    @staticmethod
-    def enable_dag() -> Response:
+    def enable_dag(self) -> Response:
         """
         Given a DAG ID, mark the dag as enabled
         """
-        request_json = request.get_json()
+        dag_id = self.get_request_dag_id()
 
-        raw_dag_id = request_json.get("dag_id")
-        if not raw_dag_id:
-            return ApiResponse.bad_request(f"Missing dag_id argument in the request")
-
-        dag_id = clean_dag_id(raw_dag_id)
+        if not dag_id:
+            return ApiResponse.bad_request(MISSING_DAG_ID_EXCEPTION_MSG)
 
         try:
             return enable_dag(dag_id)
@@ -333,18 +328,14 @@ class REST_API(AppBuilderBaseView):
                 error=f"Failed to get last run logs for '{dag_id}' due to {exc} - {traceback.format_exc()}",
             )
 
-    @staticmethod
-    def disable_dag() -> Response:
+    def disable_dag(self) -> Response:
         """
         Given a DAG ID, mark the dag as disabled
         """
-        request_json = request.get_json()
+        dag_id = self.get_request_dag_id()
 
-        raw_dag_id = request_json.get("dag_id")
-        if not raw_dag_id:
-            return ApiResponse.bad_request(f"Missing dag_id argument in the request")
-
-        dag_id = clean_dag_id(raw_dag_id)
+        if not dag_id:
+            return ApiResponse.bad_request(MISSING_DAG_ID_EXCEPTION_MSG)
 
         try:
             return disable_dag(dag_id)
@@ -355,3 +346,23 @@ class REST_API(AppBuilderBaseView):
                 status=ApiResponse.STATUS_SERVER_ERROR,
                 error=f"Failed to get last run logs for '{dag_id}' due to {exc} - {traceback.format_exc()}",
             )
+
+    def kill_all(self) -> Response:
+        """
+        Given a DAG ID, mark all running tasks as FAILED
+        to kill the processes' execution.
+        """
+        dag_id = self.get_request_dag_id()
+
+        if not dag_id:
+            return ApiResponse.bad_request(MISSING_DAG_ID_EXCEPTION_MSG)
+
+        try:
+            return kill_all(dag_id)
+
+        except Exception as exc:
+            logging.info(f"Failed to get kill runs for '{dag_id}'")
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_SERVER_ERROR,
+                error=f"Failed to kill runs for '{dag_id}' due to {exc} - {traceback.format_exc()}",
+            )
